# pyreversi

pyreversi is a reversi game in your terminal


# 🚀 How to use **pyreversi**

``pyreversi``

## Other options

``pyreversi -u`` update the package

# ⚙️ Install

See [this page](INSTALL.md)

# :construction_worker: Contribution

See [this page](CONTRIBUTING.md)

# :package: Changelog

See [this page](CHANGELOG.md)


# License

MIT License

Copyright (c) 2021 [thib1984](https://github.com/thib1984)

See [this page](LICENSE.txt) for details
